@@ -7,11 +7,11 @@
 **
 */
 
-#include "vine.h"
-#include "likelihood.h"
-#include "hfunc.h"
-#include "deriv.h"
-#include "tcopuladeriv.h"
+#include "VineCopula/vine.h"
+#include "VineCopula/likelihood.h"
+#include "VineCopula/hfunc.h"
+#include "VineCopula/deriv.h"
+#include "VineCopula/tcopuladeriv.h"
 
 #define UMAX  1-1e-10
 #define UMIN  1e-10
