@@ -2,12 +2,12 @@
 docheck <- FALSE
 
 if(docheck){
-  
+
 ### tests from excluded examples
 library(VineCopula)
 data(daxreturns)
 
-## Not run: 
+## Not run:
 # simulate from a bivariate Clayton copula
 set.seed(123)
 simdata <- BiCopSim(300, 3, 2)
@@ -26,7 +26,7 @@ gof$p.value.KS
 # End(Not run)
 
 
-## Not run: 
+## Not run:
 # simulate from a t-copula
 set.seed(123)
 dat <- BiCopSim(500, 2, 0.7, 5)
@@ -38,7 +38,7 @@ vcgof <- BiCopVuongClarke(dat[,1], dat[,2], familyset = c(1:10))
 vcgof[1,]
 # End(Not run)
 
-## Not run: 
+## Not run:
 # select the R-vine structure, families and parameters
 RVM <- RVineStructureSelect(daxreturns[,1:5], c(1:6))
 RVM$Matrix
@@ -59,16 +59,16 @@ clarke$p.value
 clarke$p.value.Schwarz
 # End(Not run)
 
-## Not run: 
+## Not run:
 # White test with asymptotic p-value
 RVineGofTest(daxreturns[,1:5], RVM, B = 0)
 
-# ECP2 test with Cramer-von-Mises test statistic and a bootstrap with 200 replications 
+# ECP2 test with Cramer-von-Mises test statistic and a bootstrap with 200 replications
 # for the calculation of the p-value
 RVineGofTest(daxreturns[,1:5], RVM, method = "ECP2", statistic = "CvM", B = 200)
 # End(Not run)
 
-## Not run: 
+## Not run:
 # define 5-dimensional R-vine tree structure matrix
 Matrix <- c(5, 2, 3, 1, 4,
             0, 2, 3, 4, 1,
@@ -109,7 +109,7 @@ mle <- RVineMLE(simdata, RVM, grad = TRUE)
 mle$RVM
 # End(Not run)
 
-## Not run: 
+## Not run:
 # PIT data
 pit <- RVinePIT(daxreturns[,1:5], RVM)
 
@@ -122,16 +122,16 @@ cor(pit, method = "kendall")
 # End(Not run)
 
 ##TODO shorten this test, takes too long
-# # Not run: 
+# # Not run:
 # RVM <- RVineStructureSelect(daxreturns, c(1:6), progress=TRUE)
 # # End(Not run)
-# 
+#
 # # specify a C-vine copula model with only Clayton, Gumbel and Frank copulas
-# # Not run: 
+# # Not run:
 # CVM <- RVineStructureSelect(daxreturns, c(3,4,5), "CVine")
 # # End(Not run)
 # # determine the order of the nodes in a D-vine using the package TSP
-# # Not run: 
+# # Not run:
 # library(TSP)
 # d <- dim(daxreturns)[2]
 # M <- 1 - abs(TauMatrix(daxreturns))
@@ -142,7 +142,7 @@ cor(pit, method = "kendall")
 # RVineCopSelect(daxreturns, c(1:6), DVM$Matrix)
 # End(Not run)
 
-## Not run: 
+## Not run:
 RVM <- RVineStructureSelect(daxreturns[,1:5], c(1:6))
 CVM <- RVineStructureSelect(daxreturns[,1:5], c(1:6), type = "CVine")
 
@@ -154,12 +154,4 @@ vuong$p.value
 vuong$p.value.Schwarz
 # End(Not run)
 
-## Not run: 
-library(copula)
-vine <- vineCopula(4L, "CVine")
-
-set.seed(123)
-rCopula(500, vine)
-# End(Not run)
-  
-}
\ No newline at end of file
+}
